@@ -21,7 +21,7 @@ class ForamAggregateAgent(Addressable):
     def step(self):
         for foram in self.forams.values():
             foram.step()
-        self.environment.tick()
+        self.environment.tick(self.parent.steps)
 
     def remove_foram(self, address):
         foram = self.forams[address]
@@ -35,7 +35,7 @@ class ForamAggregateAgent(Addressable):
 
 
 class Foram(Addressable):
-    @Inject("genom_factory")
+    @Inject("genom_factory", "reproduction_minimum", "movement_energy", "growth_minimum", "energy_need")
     def __init__(self, energy, genom=None):
         super(Foram, self).__init__()
         self.energy = energy
@@ -75,7 +75,7 @@ class Foram(Addressable):
         return capacity
 
     def _energy_demand(self):
-        return 0.2 * (self.chambers + 1)
+        return self.energy_need * (self.chambers + 1)
 
     def _take_algae(self, capacity):
         taken = 0
@@ -89,7 +89,7 @@ class Foram(Addressable):
         return taken
 
     def _can_reproduce(self):
-        return self.energy > 10 and self.genom.chambers_limit <= self.chambers
+        return self.energy > self.reproduction_minimum and self.genom.chambers_limit <= self.chambers
 
     @counted
     def _reproduce(self):
@@ -113,7 +113,7 @@ class Foram(Addressable):
                        key=lambda c: random() + c.available_food() + sum(s.available_food() for s in c.neighbours))
             if cell:
                 cell.insert_foram(self.cell.remove_foram())
-                self.energy -= 0.25
+                self.energy -= self.movement_energy
                 logger.debug("%s moved" % self)
         except:
             logging.exception("could not move")
@@ -128,8 +128,7 @@ class Foram(Addressable):
         self.cell.remove_foram()
 
     def _can_create_chamber(self):
-        # TODO hardcoded energy levels
-        return self.energy > 10 and self.genom.chambers_limit > self.chambers
+        return self.energy > self.growth_minimum and self.genom.chambers_limit > self.chambers
 
     def _create_chamber(self):
         self.energy -= 5
